==> foundation-2.6.1.tgz: package/HearingAid/HearingAid.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const HearingAid = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M47.484 28.548c-11.263 0-20.424 9.236-20.424 20.586 0 1.848 1.489 3.349 3.319 3.349 1.833 0 3.323-1.501 3.323-3.349 0-7.654 6.182-13.887 13.782-13.887 7.598 0 13.777 6.232 13.777 13.887 0 1.615-.271 3.192-.729 4.521-.872 1.553-2.828 4.861-4.005 6.305-.231.281-.462.549-.694.811-1.647 1.898-3.704 4.261-3.559 9.344.092 3.171.146 6.25-.061 7.299l-.062.355c-.151.877-.338 1.963-4.407 2.105a3.305 3.305 0 00-2.315 1.064 3.32 3.32 0 00-.891 2.398 3.321 3.321 0 003.318 3.23h.118c6.288-.217 9.894-2.797 10.757-7.844.294-1.482.339-3.547.189-8.807-.07-2.453.55-3.166 1.912-4.732.273-.312.551-.627.824-.965 1.946-2.379 4.73-7.389 4.754-7.432.081-.148.155-.305.223-.475a20.666 20.666 0 001.276-7.18c-.002-11.347-9.164-20.583-20.425-20.583z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M52.169 49.685c0 1.537 1.245 2.798 2.775 2.798 1.53 0 2.776-1.261 2.776-2.798 0-5.689-4.594-10.319-10.237-10.319-5.648 0-10.24 4.63-10.24 10.319 0 1.537 1.244 2.798 2.773 2.798 1.531 0 2.776-1.261 2.776-2.798 0-2.604 2.103-4.721 4.69-4.721 2.584 0 4.687 2.117 4.687 4.721zM33.252 59.843L19.534 73.665a3.08 3.08 0 00-.902 2.193c0 .828.319 1.604.903 2.193a3.054 3.054 0 004.352-.002l13.718-13.824c.582-.586.9-1.363.9-2.192a3.07 3.07 0 00-.899-2.188c-1.167-1.182-3.195-1.18-4.354-.002zm25.859-37.547c-.017 0-.032.004-.048.005v-.005h-1.294v.029a1.275 1.275 0 00-1.139 1.232h-.006v2.301h.031a1.263 1.263 0 001.113 1.107v.029h1.294v-.021c.016 0 .032.005.048.005 4.775 0 8.656 3.862 8.705 8.617h-.011v1.295h.03a1.275 1.275 0 001.235 1.14v.005h2.299v-.031a1.263 1.263 0 001.108-1.114h.03v-1.295h-.005c-.048-7.338-6.035-13.299-13.39-13.299z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M81.365 35.597c-.049-12.23-10.012-22.164-22.254-22.164-.017 0-.032.004-.048.005v-.005h-1.294v.029a1.273 1.273 0 00-1.14 1.237h-.005v2.298h.03a1.263 1.263 0 001.114 1.107v.029h1.294v-.02c.016 0 .032.005.048.005 9.661 0 17.519 7.832 17.568 17.478h-.01v1.295h.03a1.275 1.275 0 001.232 1.139v.006h2.302v-.031a1.263 1.263 0 001.105-1.113h.03v-1.295h-.002z"
  }));
});
HearingAid.displayName = 'HearingAid';
export const HearingAidDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/HearingAid/HearingAid.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var HearingAid = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M47.484 28.548c-11.263 0-20.424 9.236-20.424 20.586 0 1.848 1.489 3.349 3.319 3.349 1.833 0 3.323-1.501 3.323-3.349 0-7.654 6.182-13.887 13.782-13.887 7.598 0 13.777 6.232 13.777 13.887 0 1.615-.271 3.192-.729 4.521-.872 1.553-2.828 4.861-4.005 6.305-.231.281-.462.549-.694.811-1.647 1.898-3.704 4.261-3.559 9.344.092 3.171.146 6.25-.061 7.299l-.062.355c-.151.877-.338 1.963-4.407 2.105a3.305 3.305 0 00-2.315 1.064 3.32 3.32 0 00-.891 2.398 3.321 3.321 0 003.318 3.23h.118c6.288-.217 9.894-2.797 10.757-7.844.294-1.482.339-3.547.189-8.807-.07-2.453.55-3.166 1.912-4.732.273-.312.551-.627.824-.965 1.946-2.379 4.73-7.389 4.754-7.432.081-.148.155-.305.223-.475a20.666 20.666 0 001.276-7.18c-.002-11.347-9.164-20.583-20.425-20.583z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M52.169 49.685c0 1.537 1.245 2.798 2.775 2.798 1.53 0 2.776-1.261 2.776-2.798 0-5.689-4.594-10.319-10.237-10.319-5.648 0-10.24 4.63-10.24 10.319 0 1.537 1.244 2.798 2.773 2.798 1.531 0 2.776-1.261 2.776-2.798 0-2.604 2.103-4.721 4.69-4.721 2.584 0 4.687 2.117 4.687 4.721zM33.252 59.843L19.534 73.665a3.08 3.08 0 00-.902 2.193c0 .828.319 1.604.903 2.193a3.054 3.054 0 004.352-.002l13.718-13.824c.582-.586.9-1.363.9-2.192a3.07 3.07 0 00-.899-2.188c-1.167-1.182-3.195-1.18-4.354-.002zm25.859-37.547c-.017 0-.032.004-.048.005v-.005h-1.294v.029a1.275 1.275 0 00-1.139 1.232h-.006v2.301h.031a1.263 1.263 0 001.113 1.107v.029h1.294v-.021c.016 0 .032.005.048.005 4.775 0 8.656 3.862 8.705 8.617h-.011v1.295h.03a1.275 1.275 0 001.235 1.14v.005h2.299v-.031a1.263 1.263 0 001.108-1.114h.03v-1.295h-.005c-.048-7.338-6.035-13.299-13.39-13.299z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M81.365 35.597c-.049-12.23-10.012-22.164-22.254-22.164-.017 0-.032.004-.048.005v-.005h-1.294v.029a1.273 1.273 0 00-1.14 1.237h-.005v2.298h.03a1.263 1.263 0 001.114 1.107v.029h1.294v-.02c.016 0 .032.005.048.005 9.661 0 17.519 7.832 17.568 17.478h-.01v1.295h.03a1.275 1.275 0 001.232 1.139v.006h2.302v-.031a1.263 1.263 0 001.105-1.113h.03v-1.295h-.002z"
  }));
});
HearingAid.displayName = 'HearingAid';
export var HearingAidDimensions = {
  height: 100,
  width: 100
};
